@@ -54,7 +54,7 @@ our $KNOWN_BUILD_PROFILES = Lintian::Data->new('fields/build-profiles');
 
 our %KNOWN_ARCHIVE_PARTS = map { $_ => 1 } ('non-free', 'contrib');
 
-my $KNOWN_PRIOS = Lintian::Data->new('common/priorities', qr/\s*=\s*/o);
+my $KNOWN_PRIOS = Lintian::Data->new('fields/priorities');
 
 our @supported_source_formats = (qr/1\.0/, qr/3\.0\s*\((quilt|native)\)/);
 
@@ -114,8 +114,8 @@ my %VCS_EXTRACT = (
     # git uri followed by optional " -b " + branchname:
     git     => sub { return shift =~ /^(.+?)(?:\s+-b\s+(\S*))?$/;},
     svn     => sub { return @_;},
-    # that's a hostname followed by a module name:
-    mtn     => sub { return shift =~ /^(.+?)\s+(\S+)$/;},
+    # New "mtn://host?branch" uri or deprecated "host branch".
+    mtn     => sub { return shift =~ /^(.+?)(?:\s+\S+)?$/;},
 );
 my %VCS_CANONIFY = (
     browser => sub {
@@ -195,7 +195,7 @@ my %VCS_RECOMMENDED_URIS = (
     hg      => qr;^https?://;,
     git     => qr;^(?:git|https?|rsync)://;,
     svn     => qr;^(?:svn|(?:svn\+)?https?)://;,
-    mtn     => qr;^[\w.-]+$;,
+    mtn     => qr;^mtn://;,
 );
 my %VCS_VALID_URIS = (
     arch    => qr;^https?://;,
@@ -204,6 +204,7 @@ my %VCS_VALID_URIS = (
     hg      => qr;^ssh://;,
     git     => qr;^(?:git\+)?ssh://|^[\w.]+@[a-zA-Z0-9.]+:[/a-zA-Z0-9.];,
     svn     => qr;^(?:svn\+)?ssh://;,
+    mtn     => qr;^[\w.-]+$;,
 );
 
 # Python development packages that are used almost always just for building
@@ -514,7 +515,9 @@ sub run {
 
         unfold('section', \$section);
 
-        if ($type eq 'udeb') {
+        if ($section eq '') {
+            tag 'empty-section-field';
+        } elsif ($type eq 'udeb') {
             unless ($section eq 'debian-installer') {
                 tag 'wrong-section-for-udeb', $section;
             }
@@ -577,6 +580,15 @@ sub run {
 
         unfold('priority', \$priority);
 
+        if ($priority eq 'extra') {
+            tag 'priority-extra-is-replaced-by-priority-optional'
+              if $type eq 'source'
+              or not $info->is_pkg_class('auto-generated');
+            # Re-map to optional to avoid an additional warning from
+            # lintian
+            $priority = 'optional';
+        }
+
         tag 'unknown-priority', $priority
           unless $KNOWN_PRIOS->known($priority);
     }
@@ -750,7 +762,8 @@ sub run {
                       if ($field eq 'conflicts' && $d_version->[0]);
 
                     tag 'obsolete-relation-form', "$field: $part_d_orig"
-                      if ($d_version && any { $d_version->[0] eq $_ }
+                      if (
+                        $d_version && any { $d_version->[0] eq $_ }
                         ('<', '>'));
 
                     tag 'bad-version-in-relation', "$field: $part_d_orig"
